aboutsummaryrefslogtreecommitdiffstats
path: root/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothACLPackets.h
diff options
context:
space:
mode:
Diffstat (limited to 'Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothACLPackets.h')
-rw-r--r--Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothACLPackets.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothACLPackets.h b/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothACLPackets.h
index 894c37003..efe9d39f6 100644
--- a/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothACLPackets.h
+++ b/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothACLPackets.h
@@ -54,7 +54,7 @@
/** Lowest possible channel number for L2CAP data channels. */
#define BT_CHANNELNUMBER_BASEOFFSET 0x0040
/** Bluetooth specification defined channel number for signalling commands. */
#define BT_CHANNEL_SIGNALING 0x0001
/** Bluetooth specification defined channel number for connectionless data. */
@@ -105,22 +105,22 @@
uint16_t DestinationChannel; /**< Destination channel in the device the data is directed to */
} BT_DataPacket_Header_t;
/** Bluetooth signalling command header structure, for all ACL packets containing a signalling command. */
typedef struct
{
uint8_t Code; /**< Signal code, a BT_SIGNAL_* mask value */
uint8_t Identifier; /**< Unique signal command identifier to link requests and responses */
- uint16_t Length; /**< Length of the signalling command data, in bytes */
+ uint16_t Length; /**< Length of the signaling command data, in bytes */
} BT_Signal_Header_t;
/** Connection Request signalling command structure, for channel connection requests. */
typedef struct
{
uint16_t PSM; /**< Type of data the channel will carry, a CHANNEL_PSM_* mask value */
uint16_t SourceChannel; /**< Channel source on the sending device this channel will link to */
} BT_Signal_ConnectionReq_t;
/** Connection response signalling command structure, for responses to channel connection requests. */
typedef struct
{
uint16_t DestinationChannel; /**< Destination device channel that the connection request was processed on */
@@ -129,28 +129,28 @@
uint16_t Status; /**< Status of the request if the result was set to the Pending value */
} BT_Signal_ConnectionResp_t;
/** Disconnection request signalling command structure, for channel disconnection requests. */
typedef struct
{
uint16_t DestinationChannel; /**< Destination channel address which is to be disconnected */
uint16_t SourceChannel; /**< Source channel address which is to be disconnected */
} BT_Signal_DisconnectionReq_t;
/** Disconnection response signalling command structure, for responses to channel disconnection requests. */
typedef struct
{
uint16_t DestinationChannel; /**< Destination channel address which was disconnected */
uint16_t SourceChannel; /**< Source channel address which was disconnected */
} BT_Signal_DisconnectionResp_t;
/** Configuration Request signalling command structure, for channel configuration requests. */
typedef struct
{
uint16_t DestinationChannel; /**< Destination channel address which is to be disconnected */
uint16_t Flags; /**< Configuration flags for the request, including command continuation */
} BT_Signal_ConfigurationReq_t;
/** Configuration Response signalling command structure, for responses to channel configuration requests. */
typedef struct
{
uint16_t SourceChannel; /**< Source channel that the configuration request was directed at */
@@ -158,13 +158,13 @@
uint16_t Result; /**< Configuration result, a BT_CONFIGURATION_* mask value */
} BT_Signal_ConfigurationResp_t;
/** Information Request signalling command structure, for device information requests. */
typedef struct
{
uint16_t InfoType; /**< Data type that is being requested, a BT_INFOREQ_* mask value */
} BT_Signal_InformationReq_t;
/** Information Response signalling command structure, for responses to information requests. */
typedef struct
{
uint16_t InfoType; /**< Data type that was requested, a BT_INFOREQ_* mask value */
@@ -184,7 +184,7 @@
void Bluetooth_ACLTask(void);
#if defined(INCLUDE_FROM_BLUETOOTH_ACLPACKETS_C)
- static void Bluetooth_ProcessIncommingACLPackets(void);
+ static void Bluetooth_ProcessIncomingACLPackets(void);
static inline void Bluetooth_Signal_ConnectionReq(const BT_Signal_Header_t* const SignalCommandHeader);
static inline void Bluetooth_Signal_ConnectionResp(const BT_Signal_Header_t* const SignalCommandHeader);
@@ -54,7 +54,7 @@
/** Lowest possible channel number for L2CAP data channels. */
#define BT_CHANNELNUMBER_BASEOFFSET 0x0040
- /** Bluetooth specification defined channel number for signalling commands. */
+ /** Bluetooth specification defined channel number for signaling commands. */
#define BT_CHANNEL_SIGNALING 0x0001
/** Bluetooth specification defined channel number for connectionless data. */
@@ -105,22 +105,22 @@
uint16_t DestinationChannel; /**< Destination channel in the device the data is directed to */
} BT_DataPacket_Header_t;
- /** Bluetooth signalling command header structure, for all ACL packets containing a signalling command. */
+ /** Bluetooth signaling command header structure, for all ACL packets containing a signaling command. */
typedef struct
{
@@ -105,22 +105,22 @@
} BT_Signal_Header_t;
- /** Connection Request signalling command structure, for channel connection requests. */
+ /** Connection Request signaling command structure, for channel connection requests. */
typedef struct
{
@@ -105,22 +105,22 @@
uint16_t SourceChannel; /**< Channel source on the sending device this channel will link to */
} BT_Signal_ConnectionReq_t;
- /** Connection response signalling command structure, for responses to channel connection requests. */
+ /** Connection response signaling command structure, for responses to channel connection requests. */
typedef struct
{
@@ -129,28 +129,28 @@
uint16_t Status; /**< Status of the request if the result was set to the Pending value */
} BT_Signal_ConnectionResp_t;
- /** Disconnection request signalling command structure, for channel disconnection requests. */
+ /** Disconnection request signaling command structure, for channel disconnection requests. */
typedef struct
{
@@ -129,28 +129,28 @@
uint16_t SourceChannel; /**< Source channel address which is to be disconnected */
} BT_Signal_DisconnectionReq_t;
- /** Disconnection response signalling command structure, for responses to channel disconnection requests. */
+ /** Disconnection response signaling command structure, for responses to channel disconnection requests. */
typedef struct
{
@@ -129,28 +129,28 @@
uint16_t SourceChannel; /**< Source channel address which was disconnected */
} BT_Signal_DisconnectionResp_t;
- /** Configuration Request signalling command structure, for channel configuration requests. */
+ /** Configuration Request signaling command structure, for channel configuration requests. */
typedef struct
{
@@ -129,28 +129,28 @@
uint16_t Flags; /**< Configuration flags for the request, including command continuation */
} BT_Signal_ConfigurationReq_t;
- /** Configuration Response signalling command structure, for responses to channel configuration requests. */
+ /** Configuration Response signaling command structure, for responses to channel configuration requests. */
typedef struct
{
@@ -158,13 +158,13 @@
uint16_t Result; /**< Configuration result, a BT_CONFIGURATION_* mask value */
} BT_Signal_ConfigurationResp_t;
- /** Information Request signalling command structure, for device information requests. */
+ /** Information Request signaling command structure, for device information requests. */
typedef struct
{
@@ -158,13 +158,13 @@
uint16_t InfoType; /**< Data type that is being requested, a BT_INFOREQ_* mask value */
} BT_Signal_InformationReq_t;
- /** Information Response signalling command structure, for responses to information requests. */
+ /** Information Response signaling command structure, for responses to information requests. */
typedef struct
{